Struct tracing_glog::LocalTime
source · [−]pub struct LocalTime<F = Vec<FormatItem<'static>>> { /* private fields */ }Expand description
Formats the current local time using a formatter from the time crate.
To format the current UTC time instead, use the UtcTime type.
Warning: The time
crate must be compiled with --cfg unsound_local_offset in order to use
local timestamps. When this cfg is not enabled, local timestamps cannot be recorded, and
events will be logged without timestamps.
See the time
documentation for more details.