Struct tracing_glog::UtcTime
source · [−]pub struct UtcTime<F = Vec<FormatItem<'static>>> { /* private fields */ }Expand description
Formats the current UTC time using a formatter from the time crate.
To format the current local time instead, use the LocalTime type.